=== modified file 'bzrlib/tests/HTTPTestUtil.py'
--- bzrlib/tests/HTTPTestUtil.py	2006-01-10 04:39:22 +0000
+++ bzrlib/tests/HTTPTestUtil.py	2006-01-12 01:02:32 +0000
@@ -41,9 +41,4 @@
         super(TestCaseWithWebserver, self).setUp()
         self.server = HttpServer()
         self.server.setUp()
-
-    def tearDown(self):
-        try:
-            self.server.tearDown()
-        finally:
-            super(TestCaseWithWebserver, self).tearDown()
+        self.addCleanup(self.server.tearDown)

=== modified file 'bzrlib/tests/__init__.py'
--- bzrlib/tests/__init__.py	2006-01-10 05:45:16 +0000
+++ bzrlib/tests/__init__.py	2006-01-12 01:02:32 +0000
@@ -291,7 +291,7 @@
             raise AssertionError("value(s) %r not present in container %r" % 
                                  (missing, superlist))
 
-    def assertMode(self, transport, path, mode):
+    def assertTransportMode(self, transport, path, mode):
         """Fail if a path does not have mode mode.
         
         If modes are not supported on this platform, the test is skipped.

=== modified file 'bzrlib/tests/test_permissions.py'
--- bzrlib/tests/test_permissions.py	2006-01-10 05:45:16 +0000
+++ bzrlib/tests/test_permissions.py	2006-01-12 01:02:32 +0000
@@ -65,14 +65,14 @@
     assert os.path.isdir(base)
     t = get_transport(".")
     if include_base:
-        test.assertMode(t, base, dir_mode)
+        test.assertTransportMode(t, base, dir_mode)
     for root, dirs, files in os.walk(base):
         for d in dirs:
             p = os.path.join(root, d)
-            test.assertMode(t, p, dir_mode)
+            test.assertTransportMode(t, p, dir_mode)
         for f in files:
             p = os.path.join(root, f)
-            test.assertMode(t, p, file_mode)
+            test.assertTransportMode(t, p, file_mode)
 
 
 def assertEqualMode(test, mode, mode_test):
@@ -304,17 +304,17 @@
             t = SFTPTransport(self._sftp_url)
             # Direct access should be masked by umask
             t._sftp_open_exclusive('a', mode=0666).write('foo\n')
-            self.assertMode(t, 'a', 0666 &~umask)
+            self.assertTransportMode(t, 'a', 0666 &~umask)
 
             # but Transport overrides umask
             t.put('b', 'txt', mode=0666)
-            self.assertMode(t, 'b', 0666)
+            self.assertTransportMode(t, 'b', 0666)
 
             t._sftp.mkdir('c', mode=0777)
-            self.assertMode(t, 'c', 0777 &~umask)
+            self.assertTransportMode(t, 'c', 0777 &~umask)
 
             t.mkdir('d', mode=0777)
-            self.assertMode(t, 'd', 0777)
+            self.assertTransportMode(t, 'd', 0777)
         finally:
             os.umask(original_umask)
 

=== modified file 'bzrlib/tests/test_selftest.py'
--- bzrlib/tests/test_selftest.py	2006-01-10 06:01:18 +0000
+++ bzrlib/tests/test_selftest.py	2006-01-12 01:02:32 +0000
@@ -76,8 +76,15 @@
 
 
 class TestTransportProviderAdapter(TestCase):
+    """A group of tests that test the transport implementation adaption core.
+
+    This will be generalised in the future which is why it is in this 
+    test file even though it is specific to transport tests at the moment.
+    """
 
     def test_get_transport_permutations(self):
+        # this checks that we the module get_test_permutations call
+        # is made by the adapter get_transport_test_permitations method.
         class MockModule(object):
             def get_test_permutations(self):
                 return sample_permutation
@@ -88,6 +95,11 @@
                          adapter.get_transport_test_permutations(MockModule()))
 
     def test_adapter_checks_all_modules(self):
+        # this checks that the adapter returns as many permurtations as
+        # there are in all the registered# transport modules for there
+        # - we assume if this matches its probably doing the right thing
+        # especially in combination with the tests for setting the right
+        # classes below.
         from bzrlib.transport import (TransportTestProviderAdapter,
                                       _get_transport_modules
                                       )
@@ -104,6 +116,12 @@
                          len(list(iter(adapter.adapt(input_test)))))
 
     def test_adapter_sets_transport_class(self):
+        # when the adapter adapts a test it needs to 
+        # place one of the permutations from the transport
+        # providers in each test case copy. This checks
+        # that it does not just use the same one all the time.
+        # and that the id is set correctly so that debugging is
+        # easy.
         from bzrlib.transport.local import (LocalTransport,
                                             LocalRelpathServer,
                                             LocalAbspathServer,

=== modified file 'bzrlib/tests/test_sftp_transport.py'
--- bzrlib/tests/test_sftp_transport.py	2006-01-03 02:43:17 +0000
+++ bzrlib/tests/test_sftp_transport.py	2006-01-12 01:02:32 +0000
@@ -46,6 +46,7 @@
         else:
             self.server = SFTPHomeDirServer()
         self.server.setUp()
+        self.addCleanup(self.server.tearDown)
         self._sftp_url = self.server.get_url()
         self._root = self.test_dir
         # Set to a string in setUp to give sftp server a new homedir.
@@ -57,12 +58,6 @@
         # FIXME use urljoin ?
         return self._sftp_url + '/' + relpath_to_test_root
 
-    def tearDown(self):
-        try:
-            self.server.tearDown()
-        finally:
-            TestCaseInTempDir.tearDown(self)
-
     def get_transport(self, path=None):
         """Return a transport relative to self._test_root."""
         from bzrlib.transport import get_transport

=== modified file 'bzrlib/tests/test_transport_implementations.py'
--- bzrlib/tests/test_transport_implementations.py	2006-01-10 05:45:16 +0000
+++ bzrlib/tests/test_transport_implementations.py	2006-01-12 01:02:32 +0000
@@ -35,10 +35,10 @@
 def _append(fn, txt):
     """Append the given text (file-like object) to the supplied filename."""
     f = open(fn, 'ab')
-    f.write(txt.read())
-    f.flush()
-    f.close()
-    del f
+    try:
+        f.write(txt.read())
+    finally:
+        f.close()
 
 
 class TestTransportImplementation(TestCaseInTempDir):
@@ -74,7 +74,7 @@
         
     def check_transport_contents(self, content, transport, relpath):
         """Check that transport.get(relpath).read() == content."""
-        self.assertEqual(content, transport.get(relpath).read())
+        self.assertEqualDiff(content, transport.get(relpath).read())
 
     def get_transport(self):
         """Return a connected transport to the local directory."""
@@ -86,7 +86,9 @@
         return t
 
     def assertListRaises(self, excClass, func, *args, **kwargs):
-        """Many transport functions can return generators this makes sure
+        """Fail unless excClass is raised when the iterator from func is used.
+        
+        Many transport functions can return generators this makes sure
         to wrap them in a list() call to make sure the whole generator
         is run, and that the proper exception is raised.
         """
@@ -178,16 +180,16 @@
         if t.is_readonly():
             return
         t.put('mode644', StringIO('test text\n'), mode=0644)
-        self.assertMode(t, 'mode644', 0644)
+        self.assertTransportMode(t, 'mode644', 0644)
         t.put('mode666', StringIO('test text\n'), mode=0666)
-        self.assertMode(t, 'mode666', 0666)
+        self.assertTransportMode(t, 'mode666', 0666)
         t.put('mode600', StringIO('test text\n'), mode=0600)
-        self.assertMode(t, 'mode600', 0600)
+        self.assertTransportMode(t, 'mode600', 0600)
         # Yes, you can put a file such that it becomes readonly
         t.put('mode400', StringIO('test text\n'), mode=0400)
-        self.assertMode(t, 'mode400', 0400)
+        self.assertTransportMode(t, 'mode400', 0400)
         t.put_multi([('mmode644', StringIO('text\n'))], mode=0644)
-        self.assertMode(t, 'mmode644', 0644)
+        self.assertTransportMode(t, 'mmode644', 0644)
         
     def test_mkdir(self):
         t = self.get_transport()
@@ -243,16 +245,16 @@
             return
         # Test mkdir with a mode
         t.mkdir('dmode755', mode=0755)
-        self.assertMode(t, 'dmode755', 0755)
+        self.assertTransportMode(t, 'dmode755', 0755)
         t.mkdir('dmode555', mode=0555)
-        self.assertMode(t, 'dmode555', 0555)
+        self.assertTransportMode(t, 'dmode555', 0555)
         t.mkdir('dmode777', mode=0777)
-        self.assertMode(t, 'dmode777', 0777)
+        self.assertTransportMode(t, 'dmode777', 0777)
         t.mkdir('dmode700', mode=0700)
-        self.assertMode(t, 'dmode700', 0700)
+        self.assertTransportMode(t, 'dmode700', 0700)
         # TODO: jam 20051215 test mkdir_multi with a mode
         t.mkdir_multi(['mdmode755'], mode=0755)
-        self.assertMode(t, 'mdmode755', 0755)
+        self.assertTransportMode(t, 'mdmode755', 0755)
 
     def test_copy_to(self):
         from bzrlib.transport.memory import MemoryTransport
@@ -271,8 +273,7 @@
         # Test that copying into a missing directory raises
         # NoSuchFile
         if t.is_readonly():
-            os.mkdir('e')
-            open('e/f', 'wb').write('contents of e')
+            self.build_tree(['e/', 'e/f'])
         else:
             t.mkdir('e')
             t.put('e/f', StringIO('contents of e'))
@@ -294,7 +295,7 @@
             temp_transport = MemoryTransport("memory:/")
             t.copy_to(files, temp_transport, mode=mode)
             for f in files:
-                self.assertMode(temp_transport, f, mode)
+                self.assertTransportMode(temp_transport, f, mode)
 
     def test_append(self):
         t = self.get_transport()

=== modified file 'bzrlib/transport/__init__.py'
--- bzrlib/transport/__init__.py	2006-01-10 06:01:18 +0000
+++ bzrlib/transport/__init__.py	2006-01-12 01:02:32 +0000
@@ -227,7 +227,7 @@
         you may check via is_listable to determine if it will.
         """
         raise errors.TransportNotPossible("This transport has not "
-                                          "implemented iter_files_recursive."
+                                          "implemented iter_files_recursive "
                                           "(but must claim to be listable "
                                           "to trigger this error).")
 
@@ -405,7 +405,7 @@
         it if at all possible.
         """
         raise errors.TransportNotPossible("This transport has not "
-                                          "implemented list_dir."
+                                          "implemented list_dir "
                                           "(but must claim to be listable "
                                           "to trigger this error).")
 
@@ -466,7 +466,16 @@
 
 
 class Server(object):
-    """Basic server API for paths."""
+    """A Transport Server.
+    
+    The Server interface provides a server for a given transport. We use
+    these servers as loopback testing tools. For any given transport the
+    Servers it provides must either allow writing, or serve the contents
+    of os.getcwdu() at the time setUp is called.
+    
+    Note that these are real servers - they must implement all the things
+    that we want bzr transports to take advantage of.
+    """
 
     def setUp(self):
         """Setup the server to service requests."""
@@ -475,11 +484,13 @@
         """Remove the server and cleanup any resources it owns."""
 
     def get_url(self):
-        """Return a url for this server to os.getcwdu.
+        """Return a url for this server.
         
         If the transport does not represent a disk directory (i.e. it is 
-        a databse like svn, or a memory only transport, it should return
+        a database like svn, or a memory only transport, it should return
         a connection to a newly established resource for this Server.
+        Otherwise it should return a url that will provide access to the path
+        that was os.getcwdu() when setUp() was called.
         
         Subsequent calls will return the same resource.
         """
@@ -491,7 +502,12 @@
 
 
 class TransportTestProviderAdapter(object):
-    """A class which can setup transport interface tests."""
+    """A tool to generate a suite testing all transports for a single test.
+
+    This is done by copying the test once for each transport and injecting
+    the transport_class and transport_server classes into each copy. Each copy
+    is also given a new id() to make it easy to identify.
+    """
 
     def adapt(self, test):
         result = TestSuite()

